@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/ports/hs-haskell-src-1.0.1.6/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: haskell-src
-version: 1.0.1.5
-id: haskell-src-1.0.1.5-c9f37378f049d27f8c9a8a35f331bb90
+version: 1.0.1.6
+id: haskell-src-1.0.1.6-db68be88b75c366219d787fc49d1aaf9
 
 license: BSD3
 copyright:
@@ -24,22 +25,22 @@ exposed-modules: Language.Haskell.Lexer Language.Haskell.Parser
                  Language.Haskell.Syntax Language.Haskell.ParseUtils
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/haskell-src-1.0.1.5
-library-dirs: /usr/local/lib/ghc/haskell-src-1.0.1.5
-hs-libraries: HShaskell-src-1.0.1.5
+import-dirs: /usr/local/lib/ghc/haskell-src-1.0.1.6
+library-dirs: /usr/local/lib/ghc/haskell-src-1.0.1.6
+hs-libraries: HShaskell-src-1.0.1.6
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
-         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         pretty-1.1.1.0-867dcdeb02592f3d2a707618561c7b86
-         syb-0.3.7-a269c050536d4890f37a20513844e800
+depends: array-0.5.0.0-8a40db6fafcaa8a9af9e4724885ba0bf
+         base-4.7.0.2-b11c3b9ddc2bebe1a3d85499c9ea3f18
+         pretty-1.1.1.1-acc3b405212f217732bea6bb8ac62790
+         syb-0.4.1-706569d1ed7128dddfccaca8a9ef927f
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-haskell-src-1.0.1.5/html/haskell-src.haddock
-haddock-html: /usr/local/share/doc/hs-haskell-src-1.0.1.5/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-haskell-src-1.0.1.6/html/haskell-src.haddock
+haddock-html: /usr/local/share/doc/hs-haskell-src-1.0.1.6/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
